/**
 * @file modules/generated/module_cuckoo_generated.h
 * @brief Definition of module_cuckoo_deprecated written in array. Generated by json_to_array.py
 * @copyright (c) 2021 Avast Software, licensed under the MIT license
 */
 #pragma once

 #include "yaramod/types/modules/module_content.h"

 namespace yaramod {

 namespace modules {

 class Gmodule_cuckoo_deprecated : public ModuleContent
 {
 public:
    static constexpr std::size_t module_content_size = 278;
    static constexpr const char* module_content_parts[] = {
"{\"kind\": \"struct\", \"name\": \"cuckoo\", \"deprecated\": \"true\", \"attributes\": [{\"kind\": \"struct\", \"name\": \"signature\", \"attributes\": [{\"kind\": \"function\", \"name\": \"name\", \"return_type\": \"i\", \"overloads\": [{\"arguments\": [{\"type\": \"r\"}], \"documentation\": \"Deprecated function.\"}]}]}]}"
    };

    Gmodule_cuckoo_deprecated() : ModuleContent("cuckoo")
    {
        std::string content;
        content.reserve(module_content_size);
        for (std::size_t i = 0; i < 1; ++i)
            content += module_content_parts[i];
        setContent(std::move(content));
    }
 };

 } // namespace modules

 } // namespace yaramod
